faker\_file.providers.augment\_file\_from\_dir.augmenters package
=================================================================

Submodules
----------

faker\_file.providers.augment\_file\_from\_dir.augmenters.nlpaug\_augmenter module
----------------------------------------------------------------------------------

.. automodule:: faker_file.providers.augment_file_from_dir.augmenters.nlpaug_augmenter
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: faker_file.providers.augment_file_from_dir.augmenters
   :members:
   :undoc-members:
   :show-inheritance:
